@@ -5,24 +5,29 @@
 
 /* .Call calls */
 extern SEXP _BNPmix_cICS_mv_MKR(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP _BNPmix_cSLI_mv_MKR(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP _BNPmix_cSLI_mv_MKR(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _BNPmix_MAR_mv_MKR(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+
 extern SEXP _BNPmix_cDDP(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+
 extern SEXP _BNPmix_cICS(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _BNPmix_cICS_L(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _BNPmix_cICS_mv(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _BNPmix_cICS_mv_L(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _BNPmix_cICS_mv_P(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP _BNPmix_cSLI(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP _BNPmix_cSLI_L(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP _BNPmix_cSLI_mv(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP _BNPmix_cSLI_mv_L(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP _BNPmix_cSLI_mv_P(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP _BNPmix_MAR(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+
+extern SEXP _BNPmix_cSLI(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP _BNPmix_cSLI_L(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP _BNPmix_cSLI_mv(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP _BNPmix_cSLI_mv_L(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP _BNPmix_cSLI_mv_P(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+
+extern SEXP _BNPmix_MAR(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _BNPmix_MAR_L(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _BNPmix_MAR_mv(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _BNPmix_MAR_mv_L(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _BNPmix_MAR_mv_P(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+
 extern SEXP _BNPmix_BNPmix_psm(SEXP);
 extern SEXP _BNPmix_clean_partition(SEXP);
 extern SEXP _BNPmix_BNPmix_VI_LB(SEXP, SEXP);
@@ -31,7 +36,7 @@ extern SEXP _BNPmix_BNPmix_BIN(SEXP, SEXP);
 static const R_CallMethodDef CallEntries[] = {
     // REG
     {"_BNPmix_cICS_mv_MKR",     (DL_FUNC) &_BNPmix_cICS_mv_MKR,     25},
-    {"_BNPmix_cSLI_mv_MKR",     (DL_FUNC) &_BNPmix_cSLI_mv_MKR,     24},
+    {"_BNPmix_cSLI_mv_MKR",     (DL_FUNC) &_BNPmix_cSLI_mv_MKR,     27},
     {"_BNPmix_MAR_mv_MKR",      (DL_FUNC) &_BNPmix_MAR_mv_MKR,      25},
     // DDP
     {"_BNPmix_cDDP",      (DL_FUNC) &_BNPmix_cDDP,      18},
@@ -42,11 +47,11 @@ static const R_CallMethodDef CallEntries[] = {
     {"_BNPmix_cICS_mv_L", (DL_FUNC) &_BNPmix_cICS_mv_L, 21},
     {"_BNPmix_cICS_mv_P", (DL_FUNC) &_BNPmix_cICS_mv_P, 23},
     // SLI
-    {"_BNPmix_cSLI",      (DL_FUNC) &_BNPmix_cSLI,      21},
-    {"_BNPmix_cSLI_L",    (DL_FUNC) &_BNPmix_cSLI_L,    19},
-    {"_BNPmix_cSLI_mv",   (DL_FUNC) &_BNPmix_cSLI_mv,   22},
-    {"_BNPmix_cSLI_mv_L", (DL_FUNC) &_BNPmix_cSLI_mv_L, 20},
-    {"_BNPmix_cSLI_mv_P", (DL_FUNC) &_BNPmix_cSLI_mv_P, 22},
+    {"_BNPmix_cSLI",      (DL_FUNC) &_BNPmix_cSLI,      24},
+    {"_BNPmix_cSLI_L",    (DL_FUNC) &_BNPmix_cSLI_L,    22},
+    {"_BNPmix_cSLI_mv",   (DL_FUNC) &_BNPmix_cSLI_mv,   25},
+    {"_BNPmix_cSLI_mv_L", (DL_FUNC) &_BNPmix_cSLI_mv_L, 23},
+    {"_BNPmix_cSLI_mv_P", (DL_FUNC) &_BNPmix_cSLI_mv_P, 25},
     // MAR
     {"_BNPmix_MAR",       (DL_FUNC) &_BNPmix_MAR,       21},
     {"_BNPmix_MAR_L",     (DL_FUNC) &_BNPmix_MAR_L,     19},
